@@ -1,6 +1,6 @@
 ########################################################################
 #
-# $Id: SocksChain.pm,v 1.5 2009-11-14 10:20:43 gosha Exp $
+# $Id: SocksChain.pm,v 1.6 2009-11-21 20:26:05 gosha Exp $
 #
 # Copyright (C) Igor V. Okunev gosha<at>prv.mts-nn.ru 2005 - 2006
 #
@@ -17,7 +17,7 @@ use LWP::Protocol::http;
 
 @ISA = qw( LWP::Protocol::http );
 
-($VERSION='$Revision: 1.5 $')=~s/^\S+\s+(\S+)\s+.*/$1/;
+($VERSION='$Revision: 1.6 $')=~s/^\S+\s+(\S+)\s+.*/$1/;
 
 local $^W = 1;
 
@@ -68,7 +68,6 @@ sub _extra_sock_opts  # to be overridden by subclass
 sub request
 {
     my($self, $request, undef, $arg, $size, $timeout) = @_;
-    #LWP::Debug::trace('()');
 
     $size ||= 4096;
 
@@ -144,7 +143,6 @@ sub request
 	my $n = $socket->syswrite($req_buf, length($req_buf));
 	die $! unless defined($n);
 	die "short write" unless $n == length($req_buf);
-	#LWP::Debug::conns($req_buf);
     }
 
     my($code, $mess, @junk);
@@ -295,7 +293,6 @@ sub request
 	    if (($peer_http_version eq "1.1" && !$connection{close}) ||
 		$connection{"keep-alive"})
 	    {
-		LWP::Debug::debug("Keep the http connection to $host:$port");
 		$conn_cache->deposit("http", "$host:$port", $socket);
 	    }
 	}
